@@ -21,6 +21,7 @@
 #
 import unittest
 import os
+import re
 import math
 import pathlib
 import platform
@@ -39,9 +40,12 @@ else:
     xmlschema.XMLSchema.meta_schema.build()
 
 from elementpath import *
+from elementpath.namespaces import XPATH_FUNCTIONS_NAMESPACE
 from elementpath.xpath_nodes import is_document_node, is_lxml_document_node, \
     is_etree_element, is_lxml_etree_element
 from elementpath.xpath3 import XPath30Parser, XPath31Parser
+from elementpath.xpath30.xpath30_formats import PICTURE_PATTERN, \
+    int_to_roman, int_to_alphabetic, int_to_words
 
 try:
     from tests import test_xpath2_parser
@@ -342,10 +346,11 @@ class XPath30ParserTest(test_xpath2_parser.XPath2ParserTest):
         token = self.parser.parse(r'fn:analyze-string("2008-12-03", "^(\d+)\-(\d+)\-(\d+)$")')
         root = token.evaluate()
         self.assertEqual(len(root), 1)
-        ElementTree.register_namespace('', 'http://www.w3.org/2005/xpath-functions')
+
+        ElementTree.register_namespace('', XPATH_FUNCTIONS_NAMESPACE)
         self.assertEqual(
             ElementTree.tostring(root, encoding='utf-8').decode('utf-8'),
-            ANALYZE_STRING_1
+            re.sub(r'\n\s*', '', ANALYZE_STRING_1)
         )
 
         token = self.parser.parse('fn:analyze-string("A1,C15,,D24, X50,", "([A-Z])([0-9]+)")')
@@ -353,7 +358,7 @@ class XPath30ParserTest(test_xpath2_parser.XPath2ParserTest):
         self.assertEqual(len(root), 8)
         self.assertEqual(
             ElementTree.tostring(root, encoding='utf-8').decode('utf-8'),
-            ANALYZE_STRING_2
+            re.sub(r'\n\s*', '', ANALYZE_STRING_2)
         )
 
     def test_has_children_function(self):
@@ -552,7 +557,7 @@ class XPath30ParserTest(test_xpath2_parser.XPath2ParserTest):
         )
         context.variables['data'] = self.etree.XML("<a b='3'/>")
         result = self.parser.parse('fn:serialize($data, $params)').evaluate(context)
-        self.assertEqual(result.replace(b' />', b'/>'), b'<a b="3"/>')
+        self.assertEqual(result.replace(' />', '/>'), '<a b="3"/>')
 
     def test_head_function(self):
         self.assertEqual(self.parser.parse('fn:head(1 to 5)').evaluate(), 1)
@@ -709,16 +714,17 @@ class XPath30ParserTest(test_xpath2_parser.XPath2ParserTest):
         token = self.parser.parse("fn:function-lookup(xs:QName('fn:substring'), 2)('abcd', 2)")
         self.assertEqual(token.evaluate(), "bcd")
 
-        token = self.parser.parse("(fn:function-lookup(xs:QName('xs:dateTimeStamp'), 1), "
-                                  "xs:dateTime#1)[1] ('2011-11-11T11:11:11Z')")
+        with self.xsd_version_parser('1.1'):
+            token = self.parser.parse("(fn:function-lookup(xs:QName('xs:dateTimeStamp'), 1), "
+                                      "xs:dateTime#1)[1] ('2011-11-11T11:11:11Z')")
 
-        with self.assertRaises(MissingContextError):
-            token.evaluate()  # Context is required by predicate selector [1]
+            with self.assertRaises(MissingContextError):
+                token.evaluate()  # Context is required by predicate selector [1]
 
-        root = self.etree.XML('<root/>')
-        context = XPathContext(root=root)
-        dts = datatypes.DateTimeStamp.fromstring('2011-11-11T11:11:11Z')
-        self.assertEqual(token.evaluate(context), dts)
+            root = self.etree.XML('<root/>')
+            context = XPathContext(root=root)
+            dts = datatypes.DateTimeStamp.fromstring('2011-11-11T11:11:11Z')
+            self.assertEqual(token.evaluate(context), dts)
 
     def test_function_name(self):
         token = self.parser.parse("fn:function-name(fn:substring#2) ")
@@ -804,7 +810,7 @@ class XPath30ParserTest(test_xpath2_parser.XPath2ParserTest):
 
         token = self.parser.parse(
             'fn:fold-left(1 to 5, (), function($a, $b) {($b, $a)})')
-        self.assertListEqual(token.evaluate(context), [5,4,3,2,1])
+        self.assertListEqual(token.evaluate(context), [5, 4, 3, 2, 1])
 
         token = self.parser.parse(
             'fn:fold-left(1 to 5, "", fn:concat(?, ".", ?))')
@@ -844,6 +850,65 @@ class XPath30ParserTest(test_xpath2_parser.XPath2ParserTest):
         context = XPathContext(root=root)
         self.assertListEqual(token.evaluate(context), [11, 22, 33, 44, 55])
 
+    def test_picture_pattern(self):
+        self.assertListEqual(PICTURE_PATTERN.findall(''), [])
+        self.assertListEqual(PICTURE_PATTERN.findall('a'), [])
+        self.assertListEqual(PICTURE_PATTERN.findall('[y]'), ['[y]'])
+        self.assertListEqual(PICTURE_PATTERN.findall('[h01][m01][z,2-6]'),
+                             ['[h01]', '[m01]', '[z,2-6]'])
+        self.assertListEqual(PICTURE_PATTERN.findall('[H٠]:[m٠]:[s٠٠]:[f٠٠٠]'),
+                             ['[H٠]', '[m٠]', '[s٠٠]', '[f٠٠٠]'])
+        self.assertListEqual(PICTURE_PATTERN.split(' [H٠]:[m٠]:[s٠٠]:[f٠٠٠]'),
+                             [' ', ':', ':', ':', ''])
+        self.assertListEqual(PICTURE_PATTERN.findall('[y'), [])
+        self.assertListEqual(PICTURE_PATTERN.findall('[[y]'), [])
+
+    def test_int_to_roman(self):
+        self.assertRaises(TypeError, int_to_roman, 3.0)
+        self.assertEqual(int_to_roman(0), '0')
+        self.assertEqual(int_to_roman(3), 'III')
+        self.assertEqual(int_to_roman(4), 'IV')
+        self.assertEqual(int_to_roman(5), 'V')
+        self.assertEqual(int_to_roman(7), 'VII')
+        self.assertEqual(int_to_roman(9), 'IX')
+        self.assertEqual(int_to_roman(10), 'X')
+        self.assertEqual(int_to_roman(11), 'XI')
+        self.assertEqual(int_to_roman(19), 'XIX')
+        self.assertEqual(int_to_roman(20), 'XX')
+        self.assertEqual(int_to_roman(49), 'XLIX')
+        self.assertEqual(int_to_roman(100), 'C')
+        self.assertEqual(int_to_roman(489), 'CDLXXXIX')
+        self.assertEqual(int_to_roman(2999), 'MMCMXCIX')
+
+    def test_int_to_alphabetic(self):
+        self.assertEqual(int_to_alphabetic(4), 'd')
+        self.assertEqual(int_to_alphabetic(7), 'g')
+        self.assertEqual(int_to_alphabetic(25), 'y')
+        self.assertEqual(int_to_alphabetic(26), 'z')
+        self.assertEqual(int_to_alphabetic(27), 'aa')
+        self.assertEqual(int_to_alphabetic(-29), '-ac')
+        self.assertEqual(int_to_alphabetic(890), 'ahf')
+
+    def test_int_to_words(self):
+        self.assertEqual(int_to_words(1), 'one')
+        self.assertEqual(int_to_words(4), 'four')
+
+    def test_format_integer(self):
+        self.check_value("format-integer(57, 'I')", 'LVII')
+        self.check_value("format-integer(594, 'i')", 'dxciv')
+
+        self.check_value("format-integer(7, 'a')", 'g')
+        self.check_value("format-integer(-90956, 'A')", '-EDNH')
+
+        self.check_value("format-integer(123, 'w')",
+                         'one hundred and twenty-three')
+        self.check_value("format-integer(-8912, 'W')",
+                         "-EIGHT THOUSAND NINE HUNDRED AND TWELVE")
+        self.check_value("format-integer(17089674, 'Ww')",
+                         "Seventeen Million Eighty-Nine Thousand Six Hundred And Seventy-Four")
+
+        self.check_value("format-integer(123, '0000')", '0123')
+
 
 @unittest.skipIf(lxml_etree is None, "The lxml library is not installed")
 class LxmlXPath3ParserTest(XPath30ParserTest):
