@@ -11,7 +11,11 @@
 import unittest
 from unittest.mock import patch
 import xml.etree.ElementTree as ElementTree
-import lxml.etree
+
+try:
+    import lxml.etree as lxml_etree
+except ImportError:
+    lxml_etree = None
 
 from elementpath import *
 from elementpath.schema_proxy import AbstractXsdType
@@ -52,13 +56,14 @@ class XPathContextTest(unittest.TestCase):
         self.assertIsNone(context.copy().axis)
         self.assertEqual(context.copy(clear_axis=False).axis, 'children')
 
+    @unittest.skipIf(lxml_etree is None, 'lxml library is not installed')
     def test_etree_property(self):
         root = ElementTree.XML('<root/>')
         context = XPathContext(root)
         self.assertEqual(context.etree.__name__, 'xml.etree.ElementTree')
         self.assertEqual(context.etree.__name__, 'xml.etree.ElementTree')  # property caching
 
-        root = lxml.etree.XML('<root/>')
+        root = lxml_etree.XML('<root/>')
         context = XPathContext(root)
         self.assertEqual(context.etree.__name__, 'lxml.etree')
         self.assertEqual(context.etree.__name__, 'lxml.etree')
